DiscoveryEvent

Enum DiscoveryEvent 

#[non_exhaustive]
pub enum DiscoveryEvent<'path> { DebuginfodRequest { artifact: &'static str, build_id: &'path str, endpoint: &'path str, related_path: &'path Path, }, }
Available on crate feature convert only.
A potentially slow operation reported during path-based debug discovery.

Pass an observer to ElfConverter::convert_path_with_observer to surface network activity in interactive tools.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


DebuginfodRequest

A debuginfod request is about to be issued.

Fields

artifact: &'static str

Kind of companion being requested, such as debug file.

build_id: &'path str

Hexadecimal ELF build ID.

endpoint: &'path str

Debuginfod server base URL.

related_path: &'path Path

Image or debug file whose companion is being requested.